/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.api.recipes;

import javax.annotation.Nonnull;
import javax.annotation.ParametersAreNonnullByDefault;

import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.registries.IForgeRegistryEntry;

import net.dries007.tfc.api.types.Metal;

/**
 * Welding Recipe
 *
 * This takes two items and produces a single item out
 */
@ParametersAreNonnullByDefault
public class WeldingRecipe extends IForgeRegistryEntry.Impl<WeldingRecipe>
{
    private final Metal.Tier minTier;
    private final ItemStack input1;
    private final ItemStack input2;
    private final ItemStack output;

    public WeldingRecipe(ResourceLocation name, ItemStack input1, ItemStack input2, ItemStack output, Metal.Tier minTier)
    {
        this.input1 = input1;
        this.input2 = input2;
        this.output = output;
        if (input1.func_190926_b() || input2.func_190926_b() || output.func_190926_b())
            throw new IllegalArgumentException("Input and output are not allowed to be empty");

        this.minTier = minTier;

        setRegistryName(name);
    }

    @Nonnull
    public Metal.Tier getTier()
    {
        return minTier;
    }

    @Nonnull
    public ItemStack getOutput()
    {
        return output.func_77946_l();
    }

    public boolean matches(ItemStack input1, ItemStack input2)
    {
        // Need to check both orientations
        return (this.input1.func_77969_a(input1) && this.input2.func_77969_a(input2)) || (this.input1.func_77969_a(input2) && this.input2.func_77969_a(input1));
    }

}
