/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.objects.container;

import javax.annotation.ParametersAreNonnullByDefault;

import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.inventory.Container;
import net.minecraft.inventory.IContainerListener;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.util.NonNullList;

import net.dries007.tfc.TerraFirmaCraft;
import net.dries007.tfc.api.capability.heat.CapabilityItemHeat;
import net.dries007.tfc.network.PacketCapabilityContainerUpdate;

/**
 * This is a {@link IContainerListener} which will monitor containers and send any capability data changes for IForgeable or IItemHeat
 *
 * @author Choonster
 * @author AlcatrazEscapee
 */
@ParametersAreNonnullByDefault
public class CapabilityContainerListener implements IContainerListener
{
    private final EntityPlayerMP player;

    public CapabilityContainerListener(EntityPlayerMP player)
    {
        this.player = player;
    }

    /**
     * This is called to send the entire container.
     * It does not update every tick
     */
    @Override
    public void func_71110_a(final Container container, final NonNullList<ItemStack> items)
    {
        // Filter out any items from the list that shouldn't be synced
        final NonNullList<ItemStack> syncableItemsList = NonNullList.func_191197_a(items.size(), ItemStack.field_190927_a);
        for (int index = 0; index < syncableItemsList.size(); index++)
        {
            final ItemStack stack = syncableItemsList.get(index);
            if (shouldSyncItem(stack))
            {
                syncableItemsList.set(index, stack);
            }
            else
            {
                syncableItemsList.set(index, ItemStack.field_190927_a);
            }
        }

        final PacketCapabilityContainerUpdate message = new PacketCapabilityContainerUpdate(container.field_75152_c, syncableItemsList);
        if (message.hasData())
        {
            TerraFirmaCraft.getNetwork().sendTo(message, player);
        }
    }

    /**
     * This is called to send a single slot contents. It uses a modified packet factory method to accept a capability instance
     * This only gets called when a slot changes (only non-capability changes count)
     */
    @Override
    public void func_71111_a(Container container, int slotIndex, ItemStack stack)
    {
        if (!shouldSyncItem(stack)) return;

        final PacketCapabilityContainerUpdate message = new PacketCapabilityContainerUpdate(container.field_75152_c, slotIndex, stack);
        if (message.hasData())
        { // Don't send the message if there's nothing to update
            TerraFirmaCraft.getNetwork().sendTo(message, player);
        }
    }

    @Override
    public void func_71112_a(Container container, int ID, int value)
    {
    }

    @Override
    public void func_175173_a(Container container, IInventory inventory)
    {
    }

    private boolean shouldSyncItem(ItemStack stack)
    {
        return stack.hasCapability(CapabilityItemHeat.ITEM_HEAT_CAPABILITY, null);
    }
}
