/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.objects.container;

import javax.annotation.Nullable;

import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;

import net.dries007.tfc.TerraFirmaCraft;
import net.dries007.tfc.api.recipes.AnvilRecipe;
import net.dries007.tfc.api.registries.TFCRegistries;
import net.dries007.tfc.client.TFCGuiHandler;
import net.dries007.tfc.network.PacketAnvilUpdate;
import net.dries007.tfc.objects.te.TEAnvilTFC;
import net.dries007.tfc.util.IButtonHandler;

public class ContainerAnvilPlan extends ContainerTE<TEAnvilTFC> implements IButtonHandler
{
    public ContainerAnvilPlan(InventoryPlayer playerInv, TEAnvilTFC tile)
    {
        super(playerInv, tile, true);
    }

    @Override
    public void onButtonPress(int buttonID, @Nullable NBTTagCompound extraNBT)
    {
        if (extraNBT != null)
        {
            // Set the tile recipe
            String recipeName = extraNBT.func_74779_i("recipe");
            AnvilRecipe recipe = TFCRegistries.ANVIL.getValue(new ResourceLocation(recipeName));
            if (tile.setRecipe(recipe))
            {
                // Send an update to the client
                TerraFirmaCraft.getNetwork().sendToDimension(new PacketAnvilUpdate(tile), tile.func_145831_w().field_73011_w.getDimension());
            }

            // Switch to anvil GUI
            TFCGuiHandler.openGui(player.field_70170_p, tile.func_174877_v(), player, TFCGuiHandler.Type.ANVIL);
        }
    }

    @Override
    protected void addContainerSlots() {}
}
